@@ -17,7 +17,7 @@ import qitest.actions.run
 
 def configure_parser(parser):
     """Configure parser for this action"""
-    qibuild.parsers.build_parser(parser)
+    qibuild.parsers.cmake_build_parser(parser)
     qibuild.parsers.project_parser(parser)
     group = qitest.parsers.test_parser(parser, with_num_jobs=False)
     group.add_argument("-l", "--list", dest="list", action="store_true",
