@@ -18,8 +18,6 @@ def configure_parser(parser):
 
 
 def do(args):
-  """Main entry point"""
-  linguist_worktree = qilinguist.parsers.get_linguist_worktree(args)
-  projects = qilinguist.parsers.get_linguist_projects(linguist_worktree, args)
-  for project in projects:
-      project.release()
+    """Main entry point"""
+    builder = qilinguist.parsers.get_linguist_builder(args)
+    builder.build()
