@@ -171,5 +171,12 @@ class GettextProject(qilinguist.project.LinguistProject):
 
         qisys.command.call(cmd)
 
+    def install(self, destination):
+        full_dest = os.path.join(destination, "share", "locale")
+        def filter(f):
+            return f.endswith(".mo")
+        to_install = os.path.join(self.po_path, "share", "locale")
+        qisys.sh.install(to_install, full_dest, filter_fun=filter)
+
     def __repr__(self):
         return "<GettextProject %s in %s>" % (self.name, self.src)
